@@ -16,6 +16,9 @@ from .misc import (
     batch_iterator,
     batch_iterator_from_iterable,
     batch_iterator_from_sliceable,
+    elasticsearch_batch_iterator,
+    elasticsearch_iterator,
     list_iterator,
+    parquet_dataset_batch_iterator,
 )
 from .multiprocess import multiprocess, multithread, queue_worker
